var engine = function (templateManager, eventAggregator, ZHPromise, ScreenService, LibLoginController, localStorageEngine, requestDataSourceEngine, LibUtilities) {
    const BEFORE_PROJECT_STARTUP_EVENT = "beforeProjectStartup";
    var loginDefer = ZHPromise.defer();

    function setHeaderInfoAndBuildUserData(response){
        var filter = [ {
            'name': 'USER_ID',
            'operator': '=',
            'value': response.USER_ID
        }, {
            'name': 'ORGANIZATION_ID',
            'operator': '=',
            'value': response.ORGANIZATION_ID
        } ];

        requestDataSourceEngine.getDataSource('acl#/findUserData', filter).then(function(data) {
            var userData = data.dataset.findUserData[0];
            var defaultImage = window.modulesPackage ? Config.defaultImageProduct : Config.defaultImageModules;
            var userImage    = userData.IMAGE || defaultImage;
            ScreenService.setHeaderInfo(response.TRADING_NAME);
            ScreenService.buildUserData(response.USER_NAME, [response.COMPANY_NAME],
                function() {
                    LibUtilities.openLinkByMenu('myProfile');
                },
                userImage);
        });
    }

    eventAggregator.subscribe(BEFORE_PROJECT_STARTUP_EVENT, function () {
        if(typeof memoryStorage !== 'undefined') {
            localStorageEngine.getLocalVar = memoryStorage.getLocalVar;
            localStorageEngine.setLocalVar = memoryStorage.setLocalVar;
            setLocalVar = memoryStorage.setLocalVar;
            getLocalVar = memoryStorage.getLocalVar;
        }

        LibLoginController.authenticate().then(function(response) {
            setHeaderInfoAndBuildUserData(response);
            loginDefer.resolve(response);
        });
    });

    eventAggregator.subscribe("onContainerOpen", function (openEvent) {
        var container = openEvent.container;
        if(container && container.label) {
            var updatedTitle = ScreenService.i18n(container.label) + ' - Translate Management';
            templateManager.updateTitle(updatedTitle);
        }
        loginDefer.then(function(response){
            eventAggregator.publish('loginSuccess', response);
        });
    });

    this.logout = function () {
        ScreenService.confirmMessage('Deseja realmente sair do sistema?', 'ALERT', LibLoginController.logout);
    };

};

Configuration(function (ContextRegister) {
    ContextRegister.register('engine', engine);
});